@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -37,9 +37,7 @@ SmtpConfigDialog::SmtpConfigDialog(Transport *transport, QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SmtpConfigDialog::reject);
 }
 
-SmtpConfigDialog::~SmtpConfigDialog()
-{
-}
+SmtpConfigDialog::~SmtpConfigDialog() = default;
 
 void SmtpConfigDialog::okClicked()
 {
