@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGEQUEUEJOBTEST_H
-#define MESSAGEQUEUEJOBTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -27,4 +26,3 @@ private:
     void verifyOutboxContents(qlonglong count);
 };
 
-#endif
